==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/onlinejobpluginmockup/onlinejobpluginmockup.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian David",
                "Name[ca@valencia]": "Christian David",
                "Name[ca]": "Christian David",
                "Name[cs]": "Christian David",
                "Name[de]": "Christian David",
                "Name[en_GB]": "Christian David",
                "Name[es]": "Christian David",
                "Name[et]": "Christian David",
                "Name[eu]": "Christian David",
                "Name[fi]": "Christian David",
                "Name[fr]": "Christian David",
                "Name[gl]": "Christian David",
                "Name[ia]": "Christian David",
                "Name[it]": "Christian David",
                "Name[ko]": "Christian David",
                "Name[nl]": "Christian David",
                "Name[pl]": "Christian David",
                "Name[pt]": "Christian David",
                "Name[pt_BR]": "Christian David",
                "Name[ru]": "Christian David",
                "Name[sk]": "Christian David",
                "Name[sl]": "Christian David",
                "Name[sv]": "Christian David",
                "Name[uk]": "Christian David",
                "Name[x-test]": "xxChristian Davidxx",
                "Name[zh_CN]": "Christian David"
            }
        ],
        "Description": "If mapped to an account, it pretends it could handle all onlineTasks (for developers only).",
        "Description[ca@valencia]": "Si es fa el vincle amb un compte, intenta que es puguen gestionar totes les tasques en línia (només per als desenvolupadors).",
        "Description[ca]": "Si es fa el vincle amb un compte, intenta que es puguin gestionar totes les tasques en línia (només per als desenvolupadors).",
        "Description[en_GB]": "If mapped to an account, it pretends it could handle all onlineTasks (for developers only).",
        "Description[es]": "Si está asignado a una cuenta, simula que puede manejar todas las tareas en línea (solo para desarrolladores).",
        "Description[et]": "Kontoga vastendamise korral teeseldakse suutlikkust käidelda kõiki võrguülesandeid (mõeldud ainult arendajatele).",
        "Description[eu]": "Kontu batera mapatuz gero, lineako ataza guztiak erabil ditzakeenaren itxura egiten du (garatzaileentzako soilik).",
        "Description[fi]": "Jos kytketty tiliin, teeskentelee voivansa käsitellä kaikki verkkotehtävät (vain kehittäjille).",
        "Description[fr]": "S'il est associé à un compte en ligne, prétend qu'il peut traiter toutes les tâches en ligne (uniquement pour les développeurs).",
        "Description[gl]": "Se está asociado cunha conta pretende que pode xestionar todas as onlineTasks (só para desenvolvedores).",
        "Description[it]": "Se associato a un conto, simula di poter gestire tutte le attività in linea (solo per sviluppatori).",
        "Description[ko]": "계정에 매핑해 두면 모든 온라인 작업을 처리하는 것처럼 표시합니다(개발자 전용).",
        "Description[nl]": "Indien gekoppeld aan een account, pretendeert het dat het alle online taken kan afhandelen (alleen voor ontwikkelaars)",
        "Description[pl]": "Jeśli zmapowana do konta, to twierdzi, że może obsłużyć wszystkie onlineTasks (tylko dla programistów).",
        "Description[pt]": "Se estiver associado a uma conta, finge que consegue tratar de todas as tarefas 'online' (apenas para programadores).",
        "Description[pt_BR]": "Se mapeado para uma conta, espera-se que possa lidar com todas as tarefas online (apenas para desenvolvedores)",
        "Description[sk]": "Ak je namapované na účet, zabraňuje spracovaniu všetkých online úloh (len pre vývojárov)",
        "Description[sl]": "Če ima povezavo z računom, se pretvarja, da lahko obdela vse spletne naloge (samo za razvijalce).",
        "Description[sv]": "Om tilldelad till ett konto, låtsas det att det kan hantera alla nätuppgifter (bara för utvecklare).",
        "Description[uk]": "Якщо пов'язано із рахунком, імітує можливість обробки усіх інтернет-завдань (лише для розробників).",
        "Description[x-test]": "xxIf mapped to an account, it pretends it could handle all onlineTasks (for developers only).xx",
        "Description[zh_CN]": "绑定到账号上会假装可以处理所有在线任务 (仅限开发者用)",
        "EnabledByDefault": true,
        "Id": "onlinejobpluginmockup",
        "License": "GPL",
        "Name": "onlinejobpluginmockup",
        "Name[ca@valencia]": "onlinejobpluginmockup",
        "Name[ca]": "onlinejobpluginmockup",
        "Name[en_GB]": "onlinejobpluginmockup",
        "Name[es]": "onlinejobpluginmockup",
        "Name[et]": "onlinejobpluginmockup",
        "Name[eu]": "lineakolanpluginzirriborroa",
        "Name[fi]": "onlinejobpluginmockup",
        "Name[fr]": "onlinejobpluginmockup",
        "Name[gl]": "onlinejobpluginmockup",
        "Name[it]": "onlinejobpluginmockup",
        "Name[ko]": "onlinejobpluginmockup",
        "Name[nl]": "onlinejobpluginmockup",
        "Name[pl]": "onlinejobpluginmockup",
        "Name[pt]": "onlinejobpluginmockup",
        "Name[pt_BR]": "onlinejobpluginmockup",
        "Name[sk]": "onlinejobpluginmockup",
        "Name[sl]": "onlinejobpluginmockup",
        "Name[sv]": "Insticksprogram med nätjobbsattrapp",
        "Name[uk]": "onlinejobpluginmockup",
        "Name[x-test]": "xxonlinejobpluginmockupxx",
        "Name[zh_CN]": "onlinejobpluginmockup",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org"
    }
}

==> kmymoney-5.1.90.tar.xz: kmymoney-5.1.90/kmymoney/plugins/onlinejobpluginmockup/onlinejobpluginmockup.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian David",
                "Name[ca@valencia]": "Christian David",
                "Name[ca]": "Christian David",
                "Name[cs]": "Christian David",
                "Name[de]": "Christian David",
                "Name[en_GB]": "Christian David",
                "Name[eo]": "Kristana Davido",
                "Name[es]": "Christian David",
                "Name[et]": "Christian David",
                "Name[eu]": "Christian David",
                "Name[fi]": "Christian David",
                "Name[fr]": "Christian David",
                "Name[gl]": "Christian David",
                "Name[ia]": "Christian David",
                "Name[it]": "Christian David",
                "Name[ka]": "Christian David",
                "Name[ko]": "Christian David",
                "Name[nb]": "Christian David",
                "Name[nl]": "Christian David",
                "Name[pl]": "Christian David",
                "Name[pt]": "Christian David",
                "Name[pt_BR]": "Christian David",
                "Name[ru]": "Christian David",
                "Name[sk]": "Christian David",
                "Name[sl]": "Christian David",
                "Name[sv]": "Christian David",
                "Name[tr]": "Christian David",
                "Name[uk]": "Christian David",
                "Name[x-test]": "xxChristian Davidxx",
                "Name[zh_CN]": "Christian David",
                "Name[zh_TW]": "Christian David"
            }
        ],
        "Description": "If mapped to an account, it pretends it could handle all onlineTasks (for developers only).",
        "Description[ca@valencia]": "Si es fa el vincle amb un compte, intenta que es puguen gestionar totes les tasques en línia (només per als desenvolupadors).",
        "Description[ca]": "Si es fa el vincle amb un compte, intenta que es puguin gestionar totes les tasques en línia (només per als desenvolupadors).",
        "Description[en_GB]": "If mapped to an account, it pretends it could handle all onlineTasks (for developers only).",
        "Description[eo]": "Se mapite al konto, ĝi ŝajnigas, ke ĝi povus pritrakti ĉiujn retajn Taskojn (nur por programistoj).",
        "Description[es]": "Si está asignado a una cuenta, simula que puede manejar todas las tareas en línea (solo para desarrolladores).",
        "Description[et]": "Kontoga vastendamise korral teeseldakse suutlikkust käidelda kõiki võrguülesandeid (mõeldud ainult arendajatele).",
        "Description[eu]": "Kontu batera mapatuz gero, lineako ataza guztiak erabil ditzakeenaren itxura egiten du (garatzaileentzako soilik).",
        "Description[fi]": "Jos kytketty tiliin, teeskentelee voivansa käsitellä kaikki verkkotehtävät (vain kehittäjille).",
        "Description[fr]": "S'il est associé à un compte en ligne, prétend qu'il peut traiter toutes les tâches en ligne (uniquement pour les développeurs).",
        "Description[gl]": "Se está asociado cunha conta pretende que pode xestionar todas as onlineTasks (só para desenvolvedores).",
        "Description[it]": "Se associato a un conto, simula di poter gestire tutte le attività in linea (solo per sviluppatori).",
        "Description[ka]": "თუ მიბმულია ანგარიშზე, ის ამტკიცებს, რომ ყველა ონლაინ ამოცანის შესრულება შეუძლია (მხოლოდ პროგრამისტებისთვის).",
        "Description[ko]": "계정에 매핑해 두면 모든 온라인 작업을 처리하는 것처럼 표시합니다(개발자 전용).",
        "Description[nb]": "Dersom denne er tilordnet en konto vil den late som at den kan håndtere alle nettbaserte oppgaver (kun for utviklere).",
        "Description[nl]": "Indien gekoppeld aan een account, pretendeert het dat het alle online taken kan afhandelen (alleen voor ontwikkelaars)",
        "Description[pl]": "Jeśli zmapowana do konta, to twierdzi, że może obsłużyć wszystkie onlineTasks (tylko dla programistów).",
        "Description[pt]": "Se estiver associado a uma conta, finge que consegue tratar de todas as tarefas 'online' (apenas para programadores).",
        "Description[pt_BR]": "Se mapeado para uma conta, espera-se que possa lidar com todas as tarefas online (apenas para desenvolvedores)",
        "Description[ru]": "При привязке к счёту имитирует возможность обработки всех сетевых заданий (только для разработчиков)",
        "Description[sk]": "Ak je namapované na účet, zabraňuje spracovaniu všetkých online úloh (len pre vývojárov)",
        "Description[sl]": "Če ima povezavo z računom, se pretvarja, da lahko obdela vse spletne naloge (samo za razvijalce).",
        "Description[sv]": "Om tilldelad till ett konto, låtsas det att det kan hantera alla nätuppgifter (bara för utvecklare).",
        "Description[tr]": "Bir hesapla eşlenirse tüm çevrimiçi görevleri halledebilirmiş gibi görünür (yalnızca geliştiriciler için).",
        "Description[uk]": "Якщо пов'язано із рахунком, імітує можливість обробки усіх інтернет-завдань (лише для розробників).",
        "Description[x-test]": "xxIf mapped to an account, it pretends it could handle all onlineTasks (for developers only).xx",
        "Description[zh_CN]": "绑定到账户上会假装可以处理所有在线任务 (仅限开发者用)",
        "EnabledByDefault": true,
        "Id": "onlinejobpluginmockup",
        "License": "GPL",
        "Name": "onlinejobpluginmockup",
        "Name[ca@valencia]": "onlinejobpluginmockup",
        "Name[ca]": "onlinejobpluginmockup",
        "Name[en_GB]": "onlinejobpluginmockup",
        "Name[eo]": "enrettaskakromprogramimito",
        "Name[es]": "onlinejobpluginmockup",
        "Name[et]": "onlinejobpluginmockup",
        "Name[eu]": "lineakolanpluginzirriborroa",
        "Name[fi]": "onlinejobpluginmockup",
        "Name[fr]": "onlinejobpluginmockup",
        "Name[gl]": "onlinejobpluginmockup",
        "Name[it]": "onlinejobpluginmockup",
        "Name[ka]": "onlinejobpluginmockup",
        "Name[ko]": "onlinejobpluginmockup",
        "Name[nb]": "onlinejobpluginmockup",
        "Name[nl]": "onlinejobpluginmockup",
        "Name[pl]": "onlinejobpluginmockup",
        "Name[pt]": "onlinejobpluginmockup",
        "Name[pt_BR]": "onlinejobpluginmockup",
        "Name[ru]": "Макет модуля сетевых заданий",
        "Name[sk]": "onlinejobpluginmockup",
        "Name[sl]": "onlinejobpluginmockup",
        "Name[sv]": "Insticksprogram med nätjobbsattrapp",
        "Name[tr]": "çevrimiçiişeklentimockup",
        "Name[uk]": "onlinejobpluginmockup",
        "Name[x-test]": "xxonlinejobpluginmockupxx",
        "Name[zh_CN]": "onlinejobpluginmockup",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org"
    }
}
